pub struct ReplacerMarker;Trait Implementations
Sourceimpl Clone for ReplacerMarker
impl Clone for ReplacerMarker
Sourcefn clone(&self) -> ReplacerMarker
fn clone(&self) -> ReplacerMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ReplacerMarker
Sourceimpl Debug for ReplacerMarker
impl Debug for ReplacerMarker
Sourceimpl DiscoverableProtocolMarker for ReplacerMarker
impl DiscoverableProtocolMarker for ReplacerMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
impl Eq for ReplacerMarker
Sourceimpl Hash for ReplacerMarker
impl Hash for ReplacerMarker
Sourceimpl Ord for ReplacerMarker
impl Ord for ReplacerMarker
Sourcefn cmp(&self, other: &ReplacerMarker) -> Ordering
fn cmp(&self, other: &ReplacerMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for ReplacerMarker
impl PartialEq for ReplacerMarker
Sourceimpl PartialOrd for ReplacerMarker
impl PartialOrd for ReplacerMarker
Sourceimpl ProtocolMarker for ReplacerMarker
impl ProtocolMarker for ReplacerMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.examples.reverser.Replacer"
const DEBUG_NAME: &'static str = "fuchsia.examples.reverser.Replacer"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = ReplacerProxy
type Proxy = ReplacerProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = ReplacerRequestStream
type RequestStream = ReplacerRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = ReplacerSynchronousProxy
type SynchronousProxy = ReplacerSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for ReplacerMarker